@@ -77,6 +77,7 @@ func exampleInfo() *nfpm.Info {
 				PostRemove:  "../testdata/scripts/postremove.sh",
 			},
 			RPM: nfpm.RPM{
+				Prefixes: []string{"/opt"},
 				Scripts: nfpm.RPMScripts{
 					PreTrans:  "../testdata/scripts/pretrans.sh",
 					PostTrans: "../testdata/scripts/posttrans.sh",
@@ -145,6 +146,7 @@ func TestRPM(t *testing.T) {
 func TestRPMPlatform(t *testing.T) {
 	f, err := os.CreateTemp(t.TempDir(), "test*.rpm")
 	require.NoError(t, err)
+	t.Cleanup(func() { require.NoError(t, f.Close()) })
 	info := exampleInfo()
 	info.Platform = "darwin"
 	require.NoError(t, Default.Package(info, f))
